@@ -8,14 +8,14 @@
  * Licensed under the GNU GPL. For full terms see the file COPYING that came
  * with the Squirrelmail distribution.
  *
- * @version $Id: addrule.php,v 1.12 2006-05-31 10:42:00 avel Exp $
+ * @version $Id: addrule.php 935 2008-07-04 10:25:39Z avel $
  * @author Alexandros Vellis <avel@users.sourceforge.net>
  * @copyright 2004 The SquirrelMail Project Team, Alexandros Vellis
  * @package plugins
  * @subpackage avelsieve
  */
 
-
+/** Includes */
 if (file_exists('../../include/init.php')) {
     include_once('../../include/init.php');
 } else if (file_exists('../../include/validate.php')) {
@@ -27,6 +27,7 @@ if (file_exists('../../include/init.php')) {
     include_once(SM_PATH . 'functions/date.php');
 }
 
+include_once(SM_PATH . 'functions/identity.php');
 include_once(SM_PATH . 'plugins/avelsieve/config/config.php');
 include_once(SM_PATH . 'plugins/avelsieve/include/support.inc.php');
 include_once(SM_PATH . 'plugins/avelsieve/include/html_ruleedit.inc.php');
